Index: trunk/psLib/src/db/psDB.h
===================================================================
--- trunk/psLib/src/db/psDB.h	(revision 4540)
+++ trunk/psLib/src/db/psDB.h	(revision 4589)
@@ -10,6 +10,6 @@
  *  @author Joshua Hoblitt
  *
- *  @version $Revision: 1.11 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-07-12 19:12:00 $
+ *  @version $Revision: 1.12 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-07-21 01:40:10 $
  *
  *  Copyright 2005 Joshua Hoblitt, University of Hawaii
@@ -40,5 +40,5 @@
 /** Opens a new database connection
  *
- *  @return A new psDB object if the database connection is successful or NULL on
+ *  @return psDB*:      A new psDB object if the database connection is successful or NULL on
  *  failure.
  */
@@ -50,6 +50,5 @@
 );
 
-/** Closes a database connection
- */
+/** Closes a database connection  */
 void psDBCleanup(
     psDB *dbh                          ///< Database handle
@@ -58,5 +57,5 @@
 /** Creates a new database namespace
  *
- * @return true on success
+ * @return bool:    true on success
  */
 bool psDBCreate(
@@ -67,5 +66,5 @@
 /** Changes the current database namespace
  *
- * @return true on success
+ * @return bool:    true on success
  */
 bool psDBChange(
@@ -76,5 +75,5 @@
 /** Drops a database namespace
  *
- * @return true on success
+ * @return bool:    true on success
  */
 bool psDBDrop(
@@ -89,5 +88,5 @@
  * dialect is provided.  Caveat emptor.
  *
- * @return true on success
+ * @return bool:    true on success
  */
 bool p_psDBRunQuery(
@@ -114,5 +113,5 @@
  * Key" or "Key".  Comments are otherwise ignored.
  *
- * @return true on success
+ * @return bool:    true on success
  */
 bool psDBCreateTable(
@@ -124,5 +123,5 @@
 /** Deletes a database table
  *
- * @return true on success
+ * @return bool:    true on success
 */
 bool psDBDropTable(
@@ -137,5 +136,5 @@
  * entire range is returned.
  *
- * @return A psArray of strings or NULL on failure
+ * @return psArray*:    A psArray of strings or NULL on failure
  */
 psArray *psDBSelectColumn(
@@ -152,5 +151,5 @@
  * entire range is returned.  The data in the column is cast to to "pType".
  *
- * @return A psVector or NULL on failure
+ * @return psVector*:   A psVector or NULL on failure
  */
 psVector *psDBSelectColumnNum(
@@ -174,5 +173,5 @@
  * string, e.g. "", to match NULL field values.
  *
- * @return A psArray of psMetadata or NULL on failure
+ * @return psArray*:    A psArray of psMetadata or NULL on failure
  */
 psArray *psDBSelectRows(
@@ -192,5 +191,5 @@
  * specified in "row" that do not exist in "tableName", the insert will fail.
  *
- * @return true on success
+ * @return bool:    true on success
  */
 bool psDBInsertOneRow(
@@ -207,5 +206,5 @@
  * those used in psDBInsertOneRow().
  *
- * @return true on success
+ * @return bool:    true on success
  */
 bool psDBInsertRows(
@@ -220,5 +219,5 @@
  * the same psMetadata format as used in psDBInsertOneRow() & psDBInsertRows().
  *
- * @return A psArray of psMetadata or NULL on failure
+ * @return psArray*:    A psArray of psMetadata or NULL on failure
  */
 psArray *psDBDumpRows(
@@ -233,5 +232,5 @@
  * psMetadata structure where psMetadataItem.name contains the column's name.
  *
- * @return A psMetadata containing either a psArrays or psVector per column
+ * @return psMetadata*:     A psMetadata containing either a psArrays or psVector per column
  */
 psMetadata *psDBDumpCols(
@@ -249,7 +248,7 @@
  * used in psDBInsertOneRow(), etc.
  *
- * @return The number of rows modified or a negative value on error
- */
-psS64 psDBUpdateRows(
+ * @return long:    The number of rows modified or a negative value on error
+ */
+long psDBUpdateRows(
     psDB *dbh,                         ///< Database handle
     const char *tableName,             ///< Table name
@@ -266,7 +265,7 @@
  * the number of rows that were dropped, only 1 will be returned on success.
  *
- * @return The number of rows removed or a negative value on error
- */
-psS64 psDBDeleteRows(
+ * @return long:    The number of rows removed or a negative value on error
+ */
+long psDBDeleteRows(
     psDB *dbh,                         ///< Database handle
     const char *tableName,             ///< Table name
